@@ -9,7 +9,7 @@ STOP_WORDS = (
     "a|an|and|as|at|but|by|en|etc|for|if|in|is|of|on|or|the|to|v\.?|via|"
     "vs\.?|et|al|appellants?|defendants?|administrator|"
     "plaintiffs?|error|others|against|ex|parte|complainants?|original|"
-    "claimants?|devisee|executrix|executor"
+    "claimants?|devisee|executrix|executor|comm(issione)?r"
 )
 STOP_WORDS_RE = re.compile(r"^(%s)$" % STOP_WORDS)
 
@@ -17,10 +17,10 @@ STOP_WORDS_RE = re.compile(r"^(%s)$" % STOP_WORDS)
 def normalize_phrase(phrase):
     """Clean up words or phrases before sending them to be compared.
 
-     - Harmonize things like United States, USA, etc.
-     - Normalize to lower case.
-     - Remove punctuation.
-     - Remove stop words.
+    - Harmonize things like United States, USA, etc.
+    - Normalize to lower case.
+    - Remove punctuation.
+    - Remove stop words.
     """
     phrase = harmonize(phrase)
     phrase = phrase.lower()
