@@ -7,7 +7,7 @@ class Site(scotus_slip.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.back_scrape_iterable = range(5, int(self.yy) + 1)
+        self.back_scrape_iterable = list(range(5, int(self.yy) + 1))
         self.precedential = "In-chambers"
         self.court = "in-chambers"
 
