@@ -13,4 +13,4 @@ class Site(ariz.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.url = 'http://www.azcourts.gov/opinions/SearchOpinionsMemoDecs.aspx?court=998'
+        self.url = "http://www.azcourts.gov/opinions/SearchOpinionsMemoDecs.aspx?court=998"
