@@ -11,31 +11,38 @@ History:
   2014-12-15: Fixes insanity exception by tweaking the XPaths.
 """
 
+from lxml import html
+
 from juriscraper.OpinionSite import OpinionSite
 from juriscraper.lib.string_utils import convert_date_string
-from lxml import html
 
 
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.url = "http://www.courts.maine.gov/opinions_orders/supreme/publishedopinions.shtml"
+        self.url = "https://www.courts.maine.gov/courts/sjc/opinions.html"
+        self.path_root = '//table[contains(.//th[1], "Opinion")]'
+
+    def _get_cell_path(self, cell_number: int, subpath: str = "") -> str:
+        path = '//table[contains(.//th[1], "Opinion")]//td[%d]'
+        return "%s/%s" % (path, subpath) if subpath else path
 
     def _get_download_urls(self):
-        path = "//table//tr/td[2]/a[1]/@href"
+        path = "%s//td[2]/a[1]/@href" % self.path_root
         return list(self.html.xpath(path))
 
     def _get_case_names(self):
         case_names = []
-        for e in self.html.xpath("//table//tr/td[2]/a[1]"):
+        path = "%s//td[2]/a[1]" % self.path_root
+        for e in self.html.xpath(path):
             s = html.tostring(e, method="text", encoding="unicode")
             case_names.append(s)
         return case_names
 
     def _get_case_dates(self):
-        path = '//table[contains(.//th[1], "Opinion")]//tr/td[3]'
         dates = []
+        path = "%s//td[3]" % self.path_root
         for cell in self.html.xpath(path):
             date_string = cell.text_content().replace("Aguust", "August")
             dates.append(convert_date_string(date_string))
@@ -45,5 +52,5 @@ class Site(OpinionSite):
         return ["Published"] * len(self.case_names)
 
     def _get_neutral_citations(self):
-        path = "//table[position() > 1]//tr/td[1]//text()"
+        path = "%s//td[1]//text()" % self.path_root
         return list(self.html.xpath(path))
