@@ -14,13 +14,14 @@ class Site(miss.Site):
         # If it's the beginning of January, we need to make sure that we aren't
         # missing any late-coming cases from the previous year.
         today = date.today()
-        self.url = ('http://courts.ms.gov/scripts/websiteX_cgi.exe/GetOpinion?'
-                    'Year={year}&Court=Supreme+Court&Submit=Submit').format(
-            year=int(today.year) - 1
-        )
+        self.url = (
+            "http://courts.ms.gov/scripts/websiteX_cgi.exe/GetOpinion?"
+            "Year={year}&Court=Supreme+Court&Submit=Submit"
+        ).format(year=int(today.year) - 1)
         beginning_of_year = (
-            date(today.year, 1, 1) <= today <= date(today.year, 1, 15))
+            date(today.year, 1, 1) <= today <= date(today.year, 1, 15)
+        )
         if not beginning_of_year:
             # This simply aborts the crawler.
             self.status = 200
-            self.html = html.fromstring('<html></html>')
+            self.html = html.fromstring("<html></html>")
