@@ -1,8 +1,8 @@
-from juriscraper.OpinionSite import OpinionSite
-import time
 from datetime import date
 from datetime import timedelta
-from juriscraper.lib.string_utils import clean_string
+from juriscraper.lib.string_utils import convert_date_string
+from juriscraper.lib.html_utils import get_table_column_text
+from juriscraper.OpinionSite import OpinionSite
 
 
 class Site(OpinionSite):
@@ -15,32 +15,23 @@ class Site(OpinionSite):
             "begin_date=%s&end_date=%s&SortBy=date"
         ) % (begin_date, end_date)
         self.court_id = self.__module__
+        self.table_id = "scopinion"
+        self.path_base = "//table[@id='%s']" % self.table_id
 
     def _get_case_names(self):
-        return [t for t in self.html.xpath("//form/table[1]//tr/td[3]/text()")]
+        return get_table_column_text(self.html, 3, False, self.table_id)
 
     def _get_download_urls(self):
-        return [
-            href
-            for href in self.html.xpath(
-                '//form/table[1]/tr//td[4]/a[contains(.//text(), "PDF")]/@href'
-            )
-        ]
+        path = "%s//td[4]//a[contains(., 'PDF')]/@href" % self.path_base
+        return self.html.xpath(path)
 
     def _get_case_dates(self):
-        dates = []
-        for date_string in self.html.xpath("//form/table[1]/tr//td[1]/text()"):
-            dates.append(
-                date.fromtimestamp(
-                    time.mktime(
-                        time.strptime(clean_string(date_string), "%b %d, %Y")
-                    )
-                )
-            )
-        return dates
+        path = "%s//td[1]" % self.path_base
+        cells = self.html.xpath(path)
+        return [convert_date_string(cell.text_content()) for cell in cells]
 
     def _get_docket_numbers(self):
-        return [e for e in self.html.xpath("//form/table[1]/tr//td[2]/text()")]
+        return get_table_column_text(self.html, 2, False, self.table_id)
 
     def _get_precedential_statuses(self):
         return ["Published"] * len(self.case_names)
