@@ -44,7 +44,7 @@ class Site(OralArgumentSite):
 
     def _get_case_dates(self):
         path = "//td[contains(concat(' ',@class,' '),' views-field-field-argument-value')][contains(., '/')]/span/text()"
-        return map(self._return_case_date, self.html.xpath(path))
+        return list(map(self._return_case_date, self.html.xpath(path)))
 
     @staticmethod
     def _return_case_date(e):
@@ -53,7 +53,7 @@ class Site(OralArgumentSite):
 
     def _get_docket_numbers(self):
         path = "//td[contains(concat(' ',@class,' '),' views-field-field-argument-value')][contains(., '/')]/preceding-sibling::td[1]/text()"
-        return map(self._return_docket_number, self.html.xpath(path))
+        return list(map(self._return_docket_number, self.html.xpath(path)))
 
     @staticmethod
     def _return_docket_number(e):
